@@ -1,9 +1,9 @@
 from pyfacebook.models import *
 from pyfacebook.ratelimit import RateLimitHeader, RateLimit, PercentSecond
 from pyfacebook.exceptions import PyFacebookException, FacebookError, LibraryError
-from pyfacebook.api import GraphAPI, BasicDisplayAPI
+from pyfacebook.api import GraphAPI, BasicDisplayAPI, ServerSentEventAPI
 from pyfacebook.api.facebook.client import FacebookApi
 from pyfacebook.api.instagram_business.client import IGBusinessApi
 from pyfacebook.api.instagram_basic.client import IGBasicDisplayApi
 
-__version__ = "0.14.2"
+__version__ = "0.14.5"
